@@ -10,8 +10,10 @@ from workplanner import logger
 path_to_db = str(os.getenv(
     "WORKPLANNER_DATABASE_PATH", pathlib.Path.home() / "workplanner.db"
 ))
+cli = typer.Typer()
 
 
+@cli.command()
 def webserver(
     dbpath: str = path_to_db,
     host: str = "127.0.0.1",
@@ -43,4 +45,4 @@ def webserver(
 
 
 if __name__ == "__main__":
-    typer.run(webserver)
+    cli()
